@@ -22,7 +22,7 @@ class WebSocketManager(mp.Process):
            >> if __name__ == "__main__"
 
     """
-    def __init__(self, type: str, codes: list, qsize: int=1000):
+    def __init__(self, type: str, codes: list, qsize: int = 1000):
         """웹소켓을 컨트롤하는 클래스의 생성자
 
         Args:
@@ -40,24 +40,32 @@ class WebSocketManager(mp.Process):
 
     async def __connect_socket(self):
         uri = "wss://api.upbit.com/websocket/v1"
-        async with websockets.connect(uri, ping_interval=60) as websocket:
-            data = [{"ticket": str(uuid.uuid4())[:6]}, {"type": self.type, "codes": self.codes, "isOnlyRealtime": True}]
-            await websocket.send(json.dumps(data))
+        async for websocket in websockets.connect(uri, ping_interval=60):
+            try:
+                data = [{
+                    "ticket": str(uuid.uuid4())[:6]
+                }, {
+                    "type": self.type,
+                    "codes": self.codes,
+                    "isOnlyRealtime": True
+                }]
+                await websocket.send(json.dumps(data))
 
-            while self.alive:
-                try:
+                while self.alive:
                     recv_data = await websocket.recv()
                     recv_data = recv_data.decode('utf8')
                     self.__q.put(json.loads(recv_data))
-                except websockets.exceptions.ConnectionClosedError:
-                    self.__q.put('ConnectionClosedError')
+            except websockets.ConnectionClosed:
+                self.__q.put('ConnectionClosedError')
+                continue
 
     def run(self):
-        self.__aloop = asyncio.get_event_loop()
-        self.__aloop.run_until_complete(self.__connect_socket())
+        #self.__aloop = asyncio.get_event_loop()
+        #self.__aloop.run_until_complete(self.__connect_socket())
+        asyncio.run(self.__connect_socket())
 
     def get(self):
-        if self.alive == False:
+        if self.alive is False:
             self.alive = True
             self.start()
         return self.__q.get()
@@ -68,8 +76,8 @@ class WebSocketManager(mp.Process):
 
 
 if __name__ == "__main__":
-    wm = WebSocketManager("ticker", ["KRW-BTC",])
-    for i in range(3):
+    wm = WebSocketManager("ticker", ["KRW-BTC", ])
+    while True:
         data = wm.get()
         print(data)
     wm.terminate()
